@@ -1,7 +1,7 @@
 try:
     from normatrix.source import color
     from normatrix.source import file_parser
-except:
+except ModuleNotFoundError:
     from normatrix.normatrix.source import color
     from normatrix.normatrix.source import file_parser
 
@@ -14,14 +14,14 @@ def get_modules(list_checkers: list) -> list:
         try:
             try:
                 check = import_module(f'normatrix.plugged.{mod}')
-            except:
+            except ModuleNotFoundError:
                 check = import_module(f'normatrix.normatrix.plugged.{mod}')
             sign = signature(check.check)
             if len(sign.parameters.keys()) != 1:
                 raise ValueError
             checkers.append(check)
-        except:
-            color.print_color("red", f"bad pluggin: plugged/{mod}")
+        except Exception as e:
+            color.print_color("red", f"bad pluggin: plugged::{mod}::error::{e}")
     return checkers
 
 def itter_mod(file: file_parser.CFileParse, checkers: list) -> (list, int):
@@ -46,8 +46,7 @@ def call_plugged(files: list, list_checkers: list, pwd: str) -> (list, int):
     nb_error = 0
     stats = []
     checkers = get_modules(list_checkers)
-    for i in range(len(files)):
-        file = files[i]
+    for i, file in enumerate(files):
         parse: file_parser.CFileParse = file_parser.parse(file, pwd)
         color.print_color("cyan", f"file [{parse.basename}] n°{i + 1}/{len(files)}...")
         curr_stat, last_nb_error = itter_mod(parse, checkers)
