@@ -12,7 +12,7 @@ class TypeLine(Enum):
 
 class CFileParse:
     def __init__(self, filepath, name):
-        """an object of a file 'parsed'"""
+        """An object of a file 'parsed'."""
         # the relative path
         # : str
         self.basename = filepath[len(name) + 1:]
@@ -44,11 +44,11 @@ def get_status(lines: str) -> (TypeLine, str):
     reg = [
         '^( ){0,}?\/\*(.*?\n{0,}){0,}\*\/',
         '^( ){0,}?\/\/.*',
-        '\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1} *\w{1,}(\*){0,} (\*){0,}\w{1,}(, {0,1}\n{0,1} *\w{1,}(\*){0,} (\*){0,}\w{1,}){0,3})\n{0,1} {0,})\)\n{\n(.*\n)*?}',
-        ' {0,}#\w{1,}.*',
-        '(typedef ){0,1}(struct )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};',
-        '(typedef ){0,1}(enum )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};',
-        '(static ){0,1}(const ){0,1}\w{1,} \*{0,}\w{1,}(\[[0-9]{0,}\]){0,1} = ((\w{0,})|({\n{0,1} {0,}\w{0,}(,\n{0,1} {0,}\w{0,}){0,})|)\n{0,1}}{0,1};'
+        '\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1} *\w{1,}(\*){0,} (\*){0,}\w{1,}(\[[0-9]{0,}\]){0,}(, {0,1}\n{0,1} *\w{1,}(\*){0,} (\*){0,}\w{1,}(\[[0-9]{0,}\]){0,}){0,3})\n{0,1} {0,})\)\n{\n(.*\n)*?}',
+        '^ {0,}#\w{1,}.*',
+        '^(typedef ){0,1}(struct )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};',
+        '^(typedef ){0,1}(enum )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};',
+        '^(static ){0,1}(const ){0,1}\w{1,} \*{0,}\w{1,}(\[[0-9]{0,}\]){0,1} = ((\w{0,})|({\n{0,1} {0,}\w{0,}(,\n{0,1} {0,}\w{0,}){0,})|)\n{0,1}}{0,1};'
     ]
     status = [
         TypeLine.COMMENT,
@@ -59,8 +59,8 @@ def get_status(lines: str) -> (TypeLine, str):
         TypeLine.ENUM,
         TypeLine.GLOBAL
     ]
-    for i in range(len(reg)):
-        res = re.search(reg[i], lines, re.MULTILINE)
+    for i, regex in enumerate(reg):
+        res = re.search(regex, lines, re.MULTILINE)
         if res != None and res.start() <= len(lines.split('\n')[0]):
             return (status[i], lines[res.start():res.end()])
     return (TypeLine.NONE, lines.split('\n')[0])
